@@ -727,6 +727,7 @@ class BaseEnvironnement(BaseEstimator):
         if not control:
             control = FitControl(
                 target_field=target_field,
+                target_checktensor=target_checktensor,
                 device=(
                     device := torch.device(
                         device if torch.cuda.is_available() else 'cpu'
@@ -848,7 +849,15 @@ class BaseEnvironnement(BaseEstimator):
                 res_loss=None,
                 exception=e
             )
-            raise
+            if isinstance(e, KeyboardInterrupt):
+                warn(
+                    "\n"
+                    "-------------------------------------\n"
+                    "Fin du trining par KeyboardInterrupt.\n"
+                    "-------------------------------------\n"
+                )
+            else:
+                raise e
         list_callbacks.end_train(self, dataset, state, control, None)
         if control.device.type != "cpu": self.to(torch.device('cpu:0'))
         self._is_fitted = True
