@@ -444,7 +444,7 @@ class ClientSSH:
         if file_name is not None or content_length:
             url += "?"
         if file_name is not None:
-            url += f"filename={file_name}"
+            url += f"file-name={file_name}"
         if content_length:
             info = list(
                 map(
